@@ -32,7 +32,6 @@
 #include "photos-enums.h"
 #include "photos-filterable.h"
 #include "photos-item-manager.h"
-#include "photos-mode-controller.h"
 #include "photos-offset-collections-controller.h"
 #include "photos-offset-favorites-controller.h"
 #include "photos-offset-overview-controller.h"
@@ -107,7 +106,11 @@ photos_view_model_reset_count (PhotosViewModel *self)
   PhotosViewModelPrivate *priv = self->priv;
 
   if (priv->reset_count_id == 0)
-    priv->reset_count_id = g_timeout_add (RESET_COUNT_TIMEOUT, photos_view_model_reset_count_timeout, self);
+    priv->reset_count_id = g_timeout_add_full (G_PRIORITY_DEFAULT,
+                                               RESET_COUNT_TIMEOUT,
+                                               photos_view_model_reset_count_timeout,
+                                               g_object_ref (self),
+                                               g_object_unref);
 }
 
 
